@@ -3,13 +3,16 @@
    Copyright (c) 2005-2006 Matthew Johnson
 
    This program is free software; you can redistribute it and/or modify it
-   under the terms of either the GNU General Public License Version 2 or the
+   under the terms of either the GNU Lesser General Public License Version 2 or the
    Academic Free Licence Version 2.1.
 
    Full licence texts are included in the COPYING file with this program.
 */
 package org.freedesktop.dbus.bin;
 
+import static org.freedesktop.dbus.Gettext._;
+import static org.freedesktop.dbus.bin.IdentifierMangler.mangle;
+
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
@@ -19,6 +22,7 @@ import java.io.InputStreamReader;
 import java.io.PrintStream;
 import java.io.Reader;
 import java.io.StringReader;
+import java.text.MessageFormat;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
@@ -51,11 +55,12 @@ import org.xml.sax.SAXException;
  */
 public class CreateInterface
 {
+   @SuppressWarnings("unchecked")
    private static String collapseType(Type t, Set<String> imports, Map<StructStruct, Type[]> structs, boolean container, boolean fullnames) throws DBusException
    {
       if (t instanceof ParameterizedType) {
          String s;
-         Class c = (Class) ((ParameterizedType) t).getRawType();
+         Class<? extends Object> c = (Class<? extends Object>) ((ParameterizedType) t).getRawType();
          if (null != structs && t instanceof DBusStructType) {
             int num = 1;
             String name = "Struct";
@@ -74,7 +79,7 @@ public class CreateInterface
          s = s.replaceAll(",$", ">");
          return s;
       } else if (t instanceof Class) {
-         Class c = (Class) t;
+         Class<? extends Object> c = (Class<? extends Object>) t;
          if (c.isArray()) {
             return collapseType(c.getComponentType(), imports, structs, container, fullnames)+"[]";
          } else {
@@ -87,7 +92,7 @@ public class CreateInterface
             } else {
                try {
                   Field f = c.getField("TYPE");
-                  Class d = (Class) f.get(c);
+                  Class<? extends Object> d = (Class<? extends Object>) f.get(c);
                   return d.getSimpleName();
                } catch (Exception e) {
                   return c.getSimpleName();
@@ -151,7 +156,7 @@ public class CreateInterface
       Vector<Element> out = new Vector<Element>();
       if (null == meth.getAttribute("name") ||
             "".equals(meth.getAttribute("name"))) {
-         System.err.println("ERROR: Interface name was blank, failed");
+         System.err.println(_("ERROR: Method name was blank, failed"));
          System.exit(1);
       }
       String annotations = "";
@@ -189,7 +194,7 @@ public class CreateInterface
       comment = "";
       sig += parseReturns(out, imports, tuples, structs);
 
-      sig += meth.getAttribute("name")+"(";
+      sig += mangle(meth.getAttribute("name"))+"(";
 
       char defaultname = 'a';
       String params = "";
@@ -197,7 +202,7 @@ public class CreateInterface
          String type = getJavaType(arg.getAttribute("type"), imports, structs, false, false);
          String name = arg.getAttribute("name");
          if (null == name || "".equals(name)) name = ""+(defaultname++);
-         params += type+" "+name+", ";         
+         params += type+" "+mangle(name)+", ";         
       }
       return ("".equals(comment) ? "" : "   /**\n" + comment + "   */\n")
          + annotations + "  public " + sig + 
@@ -225,8 +230,8 @@ public class CreateInterface
             String type = getJavaType(arg.getAttribute("type"), imports, structs, false, false);
             String name = arg.getAttribute("name");
             if (null == name || "".equals(name)) name = ""+(defaultname++);
-            params.put(name, type);
-            porder.add(name);
+            params.put(mangle(name), type);
+            porder.add(mangle(name));
          }
       }
 
@@ -266,7 +271,7 @@ public class CreateInterface
    {
       if (null == iface.getAttribute("name") ||
             "".equals(iface.getAttribute("name"))) {
-         System.err.println("ERROR: Interface name was blank, failed");
+         System.err.println(_("ERROR: Interface name was blank, failed"));
          System.exit(1);
       }
 
@@ -435,7 +440,7 @@ public class CreateInterface
          else if ("node".equals(iface.getNodeName())) 
             parseRoot((Element) iface);
          else {
-            System.err.println("ERROR: Unknown node: "+iface.getNodeName()+".");
+            System.err.println(_("ERROR: Unknown node: ")+iface.getNodeName());
             System.exit(1);
          }
       }
@@ -568,7 +573,7 @@ public class CreateInterface
          if (name.equals(n.getNodeName())) return;
          expected += name + " or ";
       }
-      System.err.println("ERROR: Expected "+expected.replaceAll("....$", "")+", got "+n.getNodeName()+", failed.");
+      System.err.println(MessageFormat.format(_("ERROR: Expected {0}, got {1}, failed."), new Object[] { expected.replaceAll("....$", ""), n.getNodeName() }));
       System.exit(1);
    }
 
@@ -621,7 +626,7 @@ public class CreateInterface
             version();
             System.exit(0);
          } else if (p.startsWith("-")) {
-            System.err.println("ERROR: Unknown option: "+p);
+            System.err.println(_("ERROR: Unknown option: ")+p);
             printSyntax();
             System.exit(1);
          }
@@ -653,25 +658,25 @@ public class CreateInterface
 
       if (null != config.busname) try {
          DBusConnection conn = DBusConnection.getConnection(config.bus);
-         Introspectable in = (Introspectable) conn.getRemoteObject(config.busname, config.object, Introspectable.class);
+         Introspectable in = conn.getRemoteObject(config.busname, config.object, Introspectable.class);
          String id = in.Introspect();
          if (null == id) {
-            System.err.println("ERROR: Failed to get introspection data");
+            System.err.println(_("ERROR: Failed to get introspection data"));
             System.exit(1);
          }
          introspectdata = new StringReader(id);
          conn.disconnect();
       } catch (DBusException DBe) {
-         System.err.println("ERROR: Failure in DBus Communications: "+DBe.getMessage());
+         System.err.println(_("ERROR: Failure in DBus Communications: ")+DBe.getMessage());
          System.exit(1);
       } catch (DBusExecutionException DEe) {
-         System.err.println("ERROR: Failure in DBus Communications: "+DEe.getMessage());
+         System.err.println(_("ERROR: Failure in DBus Communications: ")+DEe.getMessage());
          System.exit(1);
 
       } else if (null != config.datafile) try {
          introspectdata = new InputStreamReader(new FileInputStream(config.datafile));
       } catch (FileNotFoundException FNFe) {
-         System.err.println("ERROR: Could not find introspection file: "+FNFe.getMessage());
+         System.err.println(_("ERROR: Could not find introspection file: ")+FNFe.getMessage());
          System.exit(1);
       }
       try {
