@@ -9,12 +9,13 @@
    Full licence texts are included in the COPYING file with this program.
 */
 package org.freedesktop.dbus.exceptions;
+import static org.freedesktop.dbus.Gettext._;
 
 @SuppressWarnings("serial")
 public class UnknownTypeCodeException extends DBusException implements NonFatalException
 {
    public UnknownTypeCodeException(byte code)
    {
-      super("Code "+code+" is not a valid D-Bus type.");
+      super(_("Not a valid D-Bus type code: ") + code);
    }
 }
