@@ -3,7 +3,7 @@
    Copyright (c) 2005-2006 Matthew Johnson
 
    This program is free software; you can redistribute it and/or modify it
-   under the terms of either the GNU General Public License Version 2 or the
+   under the terms of either the GNU Lesser General Public License Version 2 or the
    Academic Free Licence Version 2.1.
 
    Full licence texts are included in the COPYING file with this program.
@@ -11,12 +11,8 @@
 package org.freedesktop.dbus.test;
 
 import org.freedesktop.dbus.DBusInterface;
-import org.freedesktop.dbus.UInt16;
 import org.freedesktop.DBus.Description;
-import org.freedesktop.DBus.Method;
 
-import java.util.Map;
-import java.util.List;
 /**
  * A sample remote interface which exports one method.
  */
