@@ -3,21 +3,17 @@
    Copyright (c) 2005-2006 Matthew Johnson
 
    This program is free software; you can redistribute it and/or modify it
-   under the terms of either the GNU General Public License Version 2 or the
+   under the terms of either the GNU Lesser General Public License Version 2 or the
    Academic Free Licence Version 2.1.
 
    Full licence texts are included in the COPYING file with this program.
 */
 package org.freedesktop.dbus.test;
 
-import java.lang.reflect.Type;
-
 import java.util.List;
 import java.util.Vector;
 
-import org.freedesktop.dbus.DBusConnection;
 import org.freedesktop.dbus.DBusSerializable;
-import org.freedesktop.dbus.Marshalling;
 import org.freedesktop.dbus.exceptions.DBusException;
 
 public class TestSerializable<A> implements DBusSerializable
